Installation — django-mongonaut 0.2.6 documentation

### Navigation

- index
- next |
- previous |
- django-mongonaut 0.2.6 documentation »

# Installation

Get MongoDB:

    # TODO

Get the code:

    pip install django-mongonaut==0.2.6

Install the dependency in your settings.py:

    INSTALLED_APPS = (
    ...
    'mongonaut',
    ...
    )

You will need the following also set up:

- django.contrib.sessions
- django.contrib.messages

Note

No need for autodiscovery() with django-mongonaut!

### Navigation

- index
- next |
- previous |
- django-mongonaut 0.2.6 documentation »